@@ -25,18 +25,19 @@ import java.util.Set;
 
 /**
  * Gets the set of classes contained in a library given either as a jar file or an exploded directory.
- * 
+ *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  */
 public interface ClassAnalyzer
 {
-    // fields -----------------------------------------------------------------
-
-    String ROLE = ClassAnalyzer.class.getName();
-
-    // public methods ---------------------------------------------------------
 
+    /**
+     * <p>analyze.</p>
+     *
+     * @param url the JAR file or directory to analyze
+     * @return a {@link java.util.Set} object
+     * @throws java.io.IOException if any
+     */
     Set<String> analyze( URL url )
         throws IOException;
 }
