@@ -33,48 +33,65 @@ import java.util.Set;
  * ASM does not support.
  *
  * Adapted from http://stackoverflow.com/a/32278587/23691
- * 
+ *
  * Constant pool types:
- * 
+ *
  * @see <a href="https://docs.oracle.com/javase/specs/jvms/se9/html/jvms-4.html#jvms-4.4">JVM 9 Sepc</a>
  * @see <a href="https://docs.oracle.com/javase/specs/jvms/se10/html/jvms-4.html#jvms-4.4">JVM 10 Sepc</a>
- * 
  */
 public class ConstantPoolParser
 {
+    /** Constant <code>HEAD=0xcafebabe</code> */
     public static final int HEAD = 0xcafebabe;
 
     // Constant pool types
+
+    /** Constant <code>CONSTANT_UTF8=1</code> */
     public static final byte CONSTANT_UTF8 = 1;
 
+    /** Constant <code>CONSTANT_INTEGER=3</code> */
     public static final byte CONSTANT_INTEGER = 3;
 
+    /** Constant <code>CONSTANT_FLOAT=4</code> */
     public static final byte CONSTANT_FLOAT = 4;
 
+    /** Constant <code>CONSTANT_LONG=5</code> */
     public static final byte CONSTANT_LONG = 5;
 
+    /** Constant <code>CONSTANT_DOUBLE=6</code> */
     public static final byte CONSTANT_DOUBLE = 6;
 
+    /** Constant <code>CONSTANT_CLASS=7</code> */
     public static final byte CONSTANT_CLASS = 7;
 
+    /** Constant <code>CONSTANT_STRING=8</code> */
     public static final byte CONSTANT_STRING = 8;
 
+    /** Constant <code>CONSTANT_FIELDREF=9</code> */
     public static final byte CONSTANT_FIELDREF = 9;
 
+    /** Constant <code>CONSTANT_METHODREF=10</code> */
     public static final byte CONSTANT_METHODREF = 10;
 
+    /** Constant <code>CONSTANT_INTERFACEMETHODREF=11</code> */
     public static final byte CONSTANT_INTERFACEMETHODREF = 11;
 
+    /** Constant <code>CONSTANT_NAME_AND_TYPE=12</code> */
     public static final byte CONSTANT_NAME_AND_TYPE = 12;
 
+    /** Constant <code>CONSTANT_METHODHANDLE=15</code> */
     public static final byte CONSTANT_METHODHANDLE = 15;
 
+    /** Constant <code>CONSTANT_METHOD_TYPE=16</code> */
     public static final byte CONSTANT_METHOD_TYPE = 16;
 
+    /** Constant <code>CONSTANT_INVOKE_DYNAMIC=18</code> */
     public static final byte CONSTANT_INVOKE_DYNAMIC = 18;
-    
+
+    /** Constant <code>CONSTANT_MODULE=19</code> */
     public static final byte CONSTANT_MODULE = 19;
 
+    /** Constant <code>CONSTANT_PACKAGE=20</code> */
     public static final byte CONSTANT_PACKAGE = 20;
 
     private static final int OXF0 = 0xf0;
@@ -96,8 +113,8 @@ public class ConstantPoolParser
             return Collections.emptySet();
         }
         buf.getChar() ; buf.getChar(); // minor + ver
-        Set<Integer> classes = new HashSet<Integer>();
-        Map<Integer, String> stringConstants = new HashMap<Integer, String>();
+        Set<Integer> classes = new HashSet<>();
+        Map<Integer, String> stringConstants = new HashMap<>();
         for ( int ix = 1, num = buf.getChar(); ix < num; ix++ )
         {
             byte tag = buf.get();
@@ -107,53 +124,60 @@ public class ConstantPoolParser
                     throw new RuntimeException( "Unknown constant pool type '" + tag + "'" );
                 case CONSTANT_UTF8:
                     stringConstants.put( ix, decodeString( buf ) );
-                    continue;
+                    break;
                 case CONSTANT_CLASS:
-                case CONSTANT_STRING:
-                case CONSTANT_METHOD_TYPE:
                     classes.add( (int) buf.getChar() );
                     break;
+                case CONSTANT_METHOD_TYPE:
+                    consumeMethodType( buf );
+                    break;
                 case CONSTANT_FIELDREF:
                 case CONSTANT_METHODREF:
                 case CONSTANT_INTERFACEMETHODREF:
                 case CONSTANT_NAME_AND_TYPE:
-                    buf.getChar();
-                    buf.getChar();
+                    consumeReference( buf );
                     break;
                 case CONSTANT_INTEGER:
-                    buf.getInt();
+                    consumeInt( buf );
                     break;
                 case CONSTANT_FLOAT:
-                    buf.getFloat();
+                    consumeFloat( buf );
                     break;
                 case CONSTANT_DOUBLE:
-                    buf.getDouble();
+                    consumeDouble( buf );
                     ix++;
                     break;
                 case CONSTANT_LONG:
-                    buf.getLong();
+                    consumeLong( buf );
                     ix++;
                     break;
+                case CONSTANT_STRING:
+                    consumeString( buf );
+                    break;
                 case CONSTANT_METHODHANDLE:
-                    buf.get();
-                    buf.getChar();
+                    consumeMethodHandle( buf );
                     break;
                 case CONSTANT_INVOKE_DYNAMIC:
-                    buf.getChar();
-                    buf.getChar();
+                    consumeInvokeDynamic( buf );
                     break;
                 case CONSTANT_MODULE:
-                    buf.getChar();
+                    consumeModule( buf );
                     break;
                 case CONSTANT_PACKAGE:
-                    buf.getChar();
-                    break;  
+                    consumePackage( buf );
+                    break;
             }
         }
-        Set<String> result = new HashSet<String>();
+        Set<String> result = new HashSet<>();
         for ( Integer aClass : classes )
         {
-            result.add( stringConstants.get( aClass ) );
+            String className = stringConstants.get( aClass );
+
+            // filter out things from unnamed package, probably a false-positive
+            if ( isImportableClass( className ) )
+            {
+                result.add( className );
+            }
         }
         return result;
     }
@@ -162,6 +186,7 @@ public class ConstantPoolParser
     {
         int size = buf.getChar();
         // Explicit cast for compatibility with covariant return type on JDK 9's ByteBuffer
+        @SuppressWarnings( "RedundantCast" )
         int oldLimit = ( (Buffer) buf ).limit();
         ( (Buffer) buf ).limit( buf.position() + size );
         StringBuilder sb = new StringBuilder( size + ( size >> 1 ) + 16 );
@@ -189,4 +214,68 @@ public class ConstantPoolParser
         ( (Buffer) buf ).limit( oldLimit );
         return sb.toString();
     }
+
+    private static boolean isImportableClass( String className )
+    {
+        // without a slash, class must be in unnamed package, which can't be imported
+        return className.indexOf( '/' ) != -1;
+    }
+
+    private static void consumeMethodType( ByteBuffer buf )
+    {
+        buf.getChar();
+    }
+
+    private static void consumeReference( ByteBuffer buf )
+    {
+        buf.getChar();
+        buf.getChar();
+    }
+
+    private static void consumeInt( ByteBuffer buf )
+    {
+        buf.getInt();
+    }
+
+    private static void consumeFloat( ByteBuffer buf )
+    {
+        buf.getFloat();
+    }
+
+    private static void consumeDouble( ByteBuffer buf )
+    {
+        buf.getDouble();
+    }
+
+    private static void consumeLong( ByteBuffer buf )
+    {
+        buf.getLong();
+    }
+
+    private static void consumeString( ByteBuffer buf )
+    {
+        buf.getChar();
+    }
+
+    private static void consumeMethodHandle( ByteBuffer buf )
+    {
+        buf.get();
+        buf.getChar();
+    }
+
+    private static void consumeInvokeDynamic( ByteBuffer buf )
+    {
+        buf.getChar();
+        buf.getChar();
+    }
+
+    private static void consumeModule( ByteBuffer buf )
+    {
+        buf.getChar();
+    }
+
+    private static void consumePackage( ByteBuffer buf )
+    {
+        buf.getChar();
+    }
 }
