@@ -20,21 +20,27 @@ package org.apache.maven.shared.dependency.analyzer.asm;
  */
 
 import java.net.URL;
+import java.util.Set;
 
+import org.apache.maven.shared.dependency.analyzer.DependencyAnalyzer;
 import org.junit.Test;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 public class ASMDependencyAnalyzerTest
 {
-    private ASMDependencyAnalyzer analyzer = new ASMDependencyAnalyzer(); 
+    private final DependencyAnalyzer analyzer = new ASMDependencyAnalyzer();
 
     @Test
     public void test() throws Exception
     {
         URL jarUrl = this.getClass().getResource( "/org/objectweb/asm/ClassReader.class" );
-
+        assertThat( jarUrl ).isNotNull();
         String fileUrl = jarUrl.toString().substring( "jar:".length(), jarUrl.toString().indexOf( "!/" ) );
 
-        analyzer.analyze( new URL(fileUrl) );
+        Set<String> result = analyzer.analyze( new URL( fileUrl ) );
+
+        assertThat( result ).isNotEmpty();
     }
 
 }
